==> japhar-0.04.tar.gz: japhar-0.04/lib/libjni/src/jniobj.c <==
/* -*- Mode: C; c-file-style: "gnu" -*-
   jniobj.c -- Java Native Interface methods relating to objects.
   Created: Chris Toshok <toshok@hungry.com>, 26-Jul-1997
 */
/*
  This file is part of Japhar, the GNU Virtual Machine for Java Bytecodes.
  Japhar is a project of The Hungry Programmers, GNU, and OryxSoft.

  Copyright (C) 1997, 1998 The Hungry Programmers

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public
  License along with this library; if not, write to the Free
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
#include "jni.h"
#include "jniint.h"
#include "ClazzFile.h"
#include "qop.h"
#include "objects.h"
#include <stdlib.h>

jobject
JNIFUNC(AllocObject)(JNIEnv *env,
		     jclass clazz)
{
  ClazzFile *cls = (ClazzFile*)clazz;
  jobject new_obj = NULL;

  if (cls->access_flags & (ACC_INTERFACE | ACC_ABSTRACT))
    {
      /* throw InstantiationException */
      return NULL;
    }
  else
    {
      HungryJNIEnv *henv = (HungryJNIEnv*)env;
      new_obj = new_object(env, clazz);

      ENQUEUE((GC_obj*)new_obj, henv->_local_refs);

      return new_obj;
    }
}

jobject
JNIFUNC(NewObject)(JNIEnv *env,
		   jclass clazz,
		   jmethodID methodID,
		   ...)
{
  jobject object = (*env)->AllocObject(env, clazz);
  va_list varargs;

  if (object == NULL)
    return NULL;

  va_start(varargs, methodID);
  JNIFUNC(CallNonvirtualVoidMethodV)(env, object, methodID, varargs);
  va_end(varargs);
  
  return object;
}

jobject
JNIFUNC(NewObjectA)(JNIEnv *env,
		    jclass clazz,
		    jmethodID methodID,
		    jvalue *args)
{
  jobject object = (*env)->AllocObject(env, clazz);

  if (object == NULL)
    return NULL;

  JNIFUNC(CallNonvirtualVoidMethodA)(env, object, methodID, args);
  
  return object;
}

jobject
JNIFUNC(NewObjectV)(JNIEnv *env,
		    jclass clazz,
		    jmethodID methodID,
		    va_list args)
{
  jobject object = (*env)->AllocObject(env, clazz);

  if (object == NULL)
    return NULL;

  JNIFUNC(CallNonvirtualVoidMethodV)(env, object, methodID, args);
  
  return object;
}

jclass
JNIFUNC(GetObjectClass)(JNIEnv *env,
			jobject obj)
{
  obj_thunk *o = (obj_thunk*)obj;

  while (!IS_POST(o))
    o--;

  o ++;

  return STATIC_DATA(o);
}

jboolean
JNIFUNC(IsInstanceOf)(JNIEnv *env,
		      jobject obj,
		      jclass clazz)
{
  return JNI_FALSE;
}

jboolean
JNIFUNC(IsSameObject)(JNIEnv *env,
		      jobject ref,
		      jobject ref2)
{
  return ref == ref2;
}

==> japhar-0.05.tar.gz: japhar-0.05/lib/libjni/src/jniobj.c <==
/* -*- Mode: C; c-file-style: "gnu" -*-
   jniobj.c -- Java Native Interface methods relating to objects.
   Created: Chris Toshok <toshok@hungry.com>, 26-Jul-1997
 */
/*
  This file is part of Japhar, the GNU Virtual Machine for Java Bytecodes.
  Japhar is a project of The Hungry Programmers, GNU, and OryxSoft.

  Copyright (C) 1997, 1998 The Hungry Programmers

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
#include "jni.h"
#include "jniint.h"
#include "ClazzFile.h"
#include "qop.h"
#include "objects.h"
#include <stdlib.h>

jobject
JNIFUNC(AllocObject)(JNIEnv *env,
		     jclass clazz)
{
  ClazzFile *cls = (ClazzFile*)clazz;
  jobject new_obj = NULL;

  if (cls->access_flags & (ACC_INTERFACE | ACC_ABSTRACT))
    {
      /* throw InstantiationException */
      return NULL;
    }
  else
    {
      HungryJNIEnv *henv = (HungryJNIEnv*)env;
      japhar_object *jobj;
      new_obj = new_object(env, clazz);

      obj_to_object(new_obj, jobj);
      ENQUEUE((GC_obj*)jobj, henv->_local_refs);

      return new_obj;
    }
}

jobject
JNIFUNC(NewObject)(JNIEnv *env,
		   jclass clazz,
		   jmethodID methodID,
		   ...)
{
  jobject object = (*env)->AllocObject(env, clazz);
  va_list varargs;

  if (object == NULL)
    return NULL;

  va_start(varargs, methodID);
  JNIFUNC(CallNonvirtualVoidMethodV)(env, object, methodID, varargs);
  va_end(varargs);
  
  return object;
}

jobject
JNIFUNC(NewObjectA)(JNIEnv *env,
		    jclass clazz,
		    jmethodID methodID,
		    jvalue *args)
{
  jobject object = (*env)->AllocObject(env, clazz);

  if (object == NULL)
    return NULL;

  JNIFUNC(CallNonvirtualVoidMethodA)(env, object, methodID, args);
  
  return object;
}

jobject
JNIFUNC(NewObjectV)(JNIEnv *env,
		    jclass clazz,
		    jmethodID methodID,
		    va_list args)
{
  jobject object = (*env)->AllocObject(env, clazz);

  if (object == NULL)
    return NULL;

  JNIFUNC(CallNonvirtualVoidMethodV)(env, object, methodID, args);
  
  return object;
}

jclass
JNIFUNC(GetObjectClass)(JNIEnv *env,
			jobject obj)
{
  japhar_obj o = (japhar_obj)obj;

  return *o;
}

jboolean
JNIFUNC(IsInstanceOf)(JNIEnv *env,
		      jobject obj,
		      jclass clazz)
{
  return JNI_FALSE;
}

jboolean
JNIFUNC(IsSameObject)(JNIEnv *env,
		      jobject ref,
		      jobject ref2)
{
  return ref == ref2;
}
